==> mastapy-13.0.0.post4-py3-none-any.whl: mastapy/materials/_268.py <==
"""LubricationDetailDatabase"""

from __future__ import annotations

from typing import TYPE_CHECKING, TypeVar

from mastapy.utility.databases import _1828
from mastapy._internal.cast_exception import CastException
from mastapy._internal.python_net import python_net_import

_LUBRICATION_DETAIL_DATABASE = python_net_import(
    "SMT.MastaAPI.Materials", "LubricationDetailDatabase"
)

if TYPE_CHECKING:
    from mastapy.utility.databases import _1831, _1824


__docformat__ = "restructuredtext en"
__all__ = ("LubricationDetailDatabase",)


Self = TypeVar("Self", bound="LubricationDetailDatabase")


class LubricationDetailDatabase(_1828.NamedDatabase["_267.LubricationDetail"]):
    """LubricationDetailDatabase

    This is a mastapy class.
    """

    TYPE = _LUBRICATION_DETAIL_DATABASE
    _CastSelf = TypeVar("_CastSelf", bound="_Cast_LubricationDetailDatabase")

    class _Cast_LubricationDetailDatabase:
        """Special nested class for casting LubricationDetailDatabase to subclasses."""

        def __init__(
            self: "LubricationDetailDatabase._Cast_LubricationDetailDatabase",
            parent: "LubricationDetailDatabase",
        ):
            self._parent = parent

        @property
        def named_database(
            self: "LubricationDetailDatabase._Cast_LubricationDetailDatabase",
        ) -> "_1828.NamedDatabase":
            return self._parent._cast(_1828.NamedDatabase)

        @property
        def sql_database(
            self: "LubricationDetailDatabase._Cast_LubricationDetailDatabase",
        ) -> "_1831.SQLDatabase":
            pass

            from mastapy.utility.databases import _1831

            return self._parent._cast(_1831.SQLDatabase)

        @property
        def database(
            self: "LubricationDetailDatabase._Cast_LubricationDetailDatabase",
        ) -> "_1824.Database":
            pass

            from mastapy.utility.databases import _1824

            return self._parent._cast(_1824.Database)

        @property
        def lubrication_detail_database(
            self: "LubricationDetailDatabase._Cast_LubricationDetailDatabase",
        ) -> "LubricationDetailDatabase":
            return self._parent

        def __getattr__(
            self: "LubricationDetailDatabase._Cast_LubricationDetailDatabase", name: str
        ):
            try:
                return self.__dict__[name]
            except KeyError:
                class_name = "".join(n.capitalize() for n in name.split("_"))
                raise CastException(
                    f'Detected an invalid cast. Cannot cast to type "{class_name}"'
                ) from None

    def __init__(self: Self, instance_to_wrap: "LubricationDetailDatabase.TYPE"):
        super().__init__(instance_to_wrap)
        self._freeze()

    @property
    def cast_to(
        self: Self,
    ) -> "LubricationDetailDatabase._Cast_LubricationDetailDatabase":
        return self._Cast_LubricationDetailDatabase(self)

==> mastapy-13.0.1.post3-py3-none-any.whl: mastapy/materials/_268.py <==
"""LubricationDetailDatabase"""

from __future__ import annotations

from typing import TypeVar

from mastapy.utility.databases import _1828
from mastapy._internal.cast_exception import CastException
from mastapy._internal.python_net import python_net_import

_LUBRICATION_DETAIL_DATABASE = python_net_import(
    "SMT.MastaAPI.Materials", "LubricationDetailDatabase"
)


__docformat__ = "restructuredtext en"
__all__ = ("LubricationDetailDatabase",)


Self = TypeVar("Self", bound="LubricationDetailDatabase")


class LubricationDetailDatabase(_1828.NamedDatabase["_267.LubricationDetail"]):
    """LubricationDetailDatabase

    This is a mastapy class.
    """

    TYPE = _LUBRICATION_DETAIL_DATABASE
    _CastSelf = TypeVar("_CastSelf", bound="_Cast_LubricationDetailDatabase")

    class _Cast_LubricationDetailDatabase:
        """Special nested class for casting LubricationDetailDatabase to subclasses."""

        def __init__(
            self: "LubricationDetailDatabase._Cast_LubricationDetailDatabase",
            parent: "LubricationDetailDatabase",
        ):
            self._parent = parent

        @property
        def named_database(
            self: "LubricationDetailDatabase._Cast_LubricationDetailDatabase",
        ):
            return self._parent._cast(_1828.NamedDatabase)

        @property
        def sql_database(
            self: "LubricationDetailDatabase._Cast_LubricationDetailDatabase",
        ):
            pass

            from mastapy.utility.databases import _1831

            return self._parent._cast(_1831.SQLDatabase)

        @property
        def database(self: "LubricationDetailDatabase._Cast_LubricationDetailDatabase"):
            pass

            from mastapy.utility.databases import _1824

            return self._parent._cast(_1824.Database)

        @property
        def lubrication_detail_database(
            self: "LubricationDetailDatabase._Cast_LubricationDetailDatabase",
        ) -> "LubricationDetailDatabase":
            return self._parent

        def __getattr__(
            self: "LubricationDetailDatabase._Cast_LubricationDetailDatabase", name: str
        ):
            try:
                return self.__dict__[name]
            except KeyError:
                class_name = "".join(n.capitalize() for n in name.split("_"))
                raise CastException(
                    f'Detected an invalid cast. Cannot cast to type "{class_name}"'
                ) from None

    def __init__(self: Self, instance_to_wrap: "LubricationDetailDatabase.TYPE"):
        super().__init__(instance_to_wrap)
        self._freeze()

    @property
    def cast_to(
        self: Self,
    ) -> "LubricationDetailDatabase._Cast_LubricationDetailDatabase":
        return self._Cast_LubricationDetailDatabase(self)
